tendril.sourcing package
========================

Submodules
----------

.. toctree::

   tendril.sourcing.csil
   tendril.sourcing.customs
   tendril.sourcing.digikey
   tendril.sourcing.mouser
   tendril.sourcing.ti
   tendril.sourcing.electronics
   tendril.sourcing.orders
   tendril.sourcing.pricelist
   tendril.sourcing.vendors

Module contents
---------------

.. automodule:: tendril.sourcing
    :members:
    :undoc-members:
    :show-inheritance:

Inheritance Diagram
-------------------

.. inheritance-diagram::
   tendril.sourcing
   tendril.sourcing.csil
   tendril.sourcing.customs
   tendril.sourcing.digikey
   tendril.sourcing.electronics
   tendril.sourcing.orders
   tendril.sourcing.pricelist
   tendril.sourcing.vendors
